#
# spec file for package wayfire
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%define major_ver 0.9
%define minor_ver 0
%define libname libwf-utils0
Name:           wayfire
Version:        %{major_ver}.%{minor_ver}
Release:        1.2
Summary:        3D wayland compositor
License:        MIT
URL:            https://wayfire.org/
Source0:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
Source1:        https://github.com/WayfireWM/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz.sha256sum
# PATCH-FIX-OPENSUSE wayland.patch openSUSE uses non-standard header file locations/
Patch0:         wayland.patch
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glslang-devel
BuildRequires:  hwdata
BuildRequires:  inotify-tools-devel
BuildRequires:  meson >= 0.56.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(doctest)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(glm)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libevdev)
BuildRequires:  pkgconfig(libinput) >= 1.7.0
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(nlohmann_json)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.12
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(wf-config) >= %{major_ver}
BuildRequires:  pkgconfig(wlroots) >= 0.17.0
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xwayland)
Recommends:     wayfire-config-manager
Recommends:     wayfire-plugins-extra
Recommends:     wcm
Recommends:     wf-shell

%description
Wayfire is a wayland compositor based on wlroots. It aims to create a customizable, extendable and lightweight environment without sacrificing its appearance. If you want to gain a better impression at what it can do, see the demo videos on youtube: https://www.youtube.com/playlist?list=PLb7YRKEhWEBUIoT-a29UoJW9mhfzjpNle

%package -n %{libname}
Summary:        Library for %{name}

%description -n %{libname}
%{summary}.

%package        devel
Summary:        Devel files for %{name}
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description    devel
Development files for %{name}.

%prep
echo "`grep %{name}-%{version}.tar.xz %{SOURCE1} | grep -Eo '^[0-9a-f]+'`  %{SOURCE0}" | sha256sum -c
%autosetup -p1

%build
%meson \
 -Duse_system_wlroots=enabled \
 -Duse_system_wfconfig=enabled \
 -Dxwayland=enabled
%meson_build

%install
%meson_install
rm -rf %{buildroot}/%{_prefix}/man/wayfire.1
install -Dpm0644 wayfire.desktop %{buildroot}%{_datadir}/wayland-sessions/%{name}.desktop
find %{buildroot} -type f -name "*.a" -delete -print0

%fdupes %{buildroot}/%{_prefix}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%check
%meson_test

%files
%license LICENSE
%doc README.md wayfire.ini
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/wayland-sessions/
%{_datadir}/wayland-sessions/*.desktop
%{_mandir}/man1/wayfire.1%{?ext_man}

%files -n %{libname}
%{_libdir}/*.so.*
%{_libdir}/libwayfire-blur-base.so
%{_libdir}/%{name}/

%files devel
%{_libdir}/libwf-utils.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/%{name}

%changelog
* Wed Nov 13 2024 Shawn Dunn <sfalken@opensuse.org>
- Change BuildRequires: to wlroots >= 0.17.0 to clear unresolvable
  build
* Mon Aug 26 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.9.0:
  * session-lock-v1 protocol.
  * Bindings following the current layout.
  * Animation easings.
  * A lot of effort in this release went into improving
    the IPC socket.
  * CSS theming in wf-shell.
  * improving and adding even more plugins.
  * There were many, many bug fixes in this release.
  * Full changelog:
  - https://wayfire.org/2024/08/23/Wayfire-0-9.html.
* Thu Mar 14 2024 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.1:
  * Support for multiple new protocols:
  - shortcuts-inhibit-v1
  - fractional-scale-v1
  - wlr_drm_lease_v1 for non-desktop outputs.
  - input-method-v1 for better fcitx5 support (#2172).
    Note that the older support for input-method-v2 has also
    been improved, but is now disabled by default,
    because input-method-v1 works better in most cases.
    Nonetheless, it can be enabled again by setting
    workarounds/enable_input_method_v2 = true.
  * Wayfire's IPC has been extended with many new signals and commands:
  - Has methods to get view, output and workspace (and workspace-set)
    information.
  - Signals for view-mapped, unmapped,
    plugin-activation-state-changed and several others.
  - More plugins can be activated via the IPC, check the full
    commit log for details.
  * Wayfire supports SIGINT, SIGTERM for graceful shutdown.
  * Oswitch has binding to switch in the other direction.
  * Many crashes and bugs were fixed, including regressions.
* Mon Oct  9 2023 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.0:
  * Deleted 0001-wf-utils.patch
  * Added wayland.patch
  * Workspace sets.
  * IPC socket.
* Tue Jul  4 2023 Shawn Dunn <sfalken@opensuse.org>
- Added 0001-wf-utils.patch (gh#WayfireWM/wayfire#1790)
* Fri Dec  2 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.5:
  * Wayfire bug-fix release.
    Compatible with wf-config and wf-shell 0.7.x, wlroots 0.16.x.
* Wed Nov 30 2022 Dead Mozay <dead_mozay@opensuse.org>
- Set wlroots max version to spec.
* Mon Aug  1 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.4:
  * No changelog was made available.
* Mon Apr 18 2022 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.3:
  * Wayfire bug-fix release. Compatible with wf-config
    and wf-shell 0.7.x, wlroots 0.15.x.
  * Added BuildRequires: pango
* Wed Mar  9 2022 Dead Mozay <dead_mozay@opensuse.org>
- Add xwayland dependency.
* Sat Aug 14 2021 Dead Mozay <dead_mozay@opensuse.org>
- Fix Wayfire missing libdefault-config-backend.so (boo#1189171).
* Fri Jun 25 2021 Dead Mozay <dead_mozay@opensuse.org>
- Downgrading wlroots minimum version to spec.
* Fri Jun 25 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.2:
  * No changelog was made available.
* Sat Jun 19 2021 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.7.1
  * This is a bug-fix release of Wayfire. It also contains
    support for wlroots 0.13.
* Wed Feb  3 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.7.0:
  * Compatible with wf-config 0.7.x and wlroots 0.12.x
* Mon Nov  9 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.6.0:
  * Compatible with wlroots 0.12.0
* Mon Aug 17 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.5.0:
  * Compatible with wlroots 0.11
* Thu Apr 30 2020 Dead Mozay <dead_mozay@opensuse.org>
- Remove _service
* Mon Mar 23 2020 dead_mozay@opensuse.org
- Update to version 0.4.0:
  * Decoration buttons support
  * Animation support for context menus & tooltips
  * Improved dialogue handling
* Tue Mar 17 2020 dead_mozay@opensuse.org
- Update to version 0.3.1.git~20200315.30f384f:
  * Xwayland positioning improvements
  * tile_by_default from the simple-tile plugin now accepts a matcher string, so you can tile only certain window types by default
  * Rotating cube screensaver
  * Bindings now return a bool indicating whether the binding has been handled. This means that WCM can grab key- and button bindings now, instead of having the user manually type them
* Tue Mar 17 2020 dead_mozay@opensuse.org
- Update to version 0.3.1:
  * support libinput acceleration profiles
  * xwayland: Don't add decoration size when sending configure
  * Activate plugins for all outputs
* Thu Oct  3 2019 dead_mozay@opensuse.org
- Update to version 0.2.git~201910025.a8d1c1:
  * No user-visible changes
* Thu Oct  3 2019 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
